@@ -594,7 +594,9 @@ The following commands are available:
 	    (delete-matching-lines gnus-ignored-newsgroups))
 	  (while (not (eobp)) 
 	    (ignore-errors
-             (push (cons (read cur)
+             (push (cons (let ((p (point)))
+			   (skip-chars-forward "^ \t")
+			   (buffer-substring p (point)))
 			  (max 0 (- (1+ (read cur)) (read cur))))
 		    groups))
 	    (forward-line))))
