@@ -242,7 +242,8 @@ contents of this part.")
 	    (insert-buffer-substring (cdr (assq 'buffer cont))))
 	   ((and (setq filename (cdr (assq 'filename cont)))
 		 (not (equal (cdr (assq 'nofile cont)) "yes")))
-	    (mm-insert-file-contents filename nil nil nil nil t))
+	    (let ((coding-system-for-read mm-binary-coding-system))
+	      (mm-insert-file-contents filename nil nil nil nil t)))
 	   (t
 	    (insert (cdr (assq 'contents cont)))))
 	  (setq encoding (mm-encode-buffer type)
